@@ -1,7 +1,7 @@
 package WebService::Client;
 use Moo::Role;
 
-our $VERSION = '0.0201'; # VERSION
+our $VERSION = '0.0202'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request::Common qw(DELETE GET POST PUT);
@@ -69,16 +69,16 @@ sub delete {
 
 sub req {
     my ($self, $req) = @_;
-    $self->log($req->as_string);
+    $self->_log_request($req);
     my $res = $self->ua->request($req);
     Moo::Role->apply_roles_to_object($res, 'HTTP::Response::Stringable');
-    $self->log($res->as_string);
+    $self->_log_response($res);
 
     my $retries = $self->retries;
     while ($res->code =~ /^5/ and $retries--) {
         sleep 1;
         $res = $self->ua->request($req);
-        $self->log($res->as_string);
+        $self->_log_response($res);
     }
 
     return undef if $req->method eq 'GET' and $res->code =~ /404|410/;
@@ -101,6 +101,16 @@ sub _headers {
     return $headers;
 }
 
+sub _log_request {
+    my ($self, $req) = @_;
+    $self->log(ref($self) . " REQUEST:\n" . $req->as_string);
+}
+
+sub _log_response {
+    my ($self, $res) = @_;
+    $self->log(ref($self) . " RESPONSE:\n" . $res->as_string);
+}
+
 sub log {
     my ($self, $msg) = @_;
     return unless $self->logger;
@@ -124,7 +134,7 @@ WebService::Client - A base role for quickly and easily creating web service cli
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
